==> XIV_host_attach-1.1-suse-11-x64.tar.gz: opt/xiv/host_attach/lib/python/hostattachment/translation.py <==
WIZARD_BANNER="Welcome to the XIV host attachment wizard. This wizard will\n" + \
              "guide you through the process of attaching your host to the XIV system."
WIZARD_CONFIRMATION="Are you ready to configure this host for the XIV system?"
WIZARD_SEPERATOR="-" * 79

ATTACHMENT_TYPE_PROMPT="Would you like to discover fiber (fc) or iscsi devices?"
ONLY_ISCSI_PROMPT="Only ISCSI is supported on this platform. Would you like to set up an ISCSI attachment?"
ONLY_FC_PROMPT="Only fiber is supported on this platform. Would you like to set up an FC attachment?"

HOST_ALREADY_CONFIGURED="This host is already configured for the XIV system"
HOST_CONFIG_VALIDATION_NOTIFICATION="Please wait while the wizard validates your existing configuration..."
HOST_CONFIG_NOTIFICATION="The wizard will now configure the host for the XIV system"
HOST_CONFIG_SUCCESS="The host is now configured for the XIV system"

HOST_CONFIGURED="The host is already configured for the XIV system"

NEW_ISCSI_CONNECT="Would you like to discover a new iSCSI target?"
ISCSI_CONNECT_ADDR="Enter an XIV iSCSI discovery address:"

FC_RESCAN_PROMPT="Would you like to rescan for fiber channel storage devices now?"
ISCSI_RESCAN_PROMPT="Would you like to rescan for iSCSI storage devices now?"

HOST_CONFIG_COMPLETE="The host was successfuly configured for the XIV system"
WIZARD_ENDED="The XIV host attachment wizard successfuly configured this host"

XIV_FC_HOST_DEFINE="Please open the console and define the host with the relevant fiber channel WWPNs:"
XIV_ISCSI_HOST_DEFINE="Please open the console and define the host with the following initiator name or initiator alias:"

USER_ABORT_CONFIRM="Are you sure you want to cancel the XIV host attachment configuration wizard?"
USER_ABORT="The operation was canceld"

REBOOT_REQUIRED="A reboot is required in order to continue. Please reboot the machine and restart the wizard"

HOST_CONFIG_WAIT="Please wait while the host is configured..."
HOST_RESCAN_WAIT="Please wait while rescanning for storage devices..."

INPUT_INVALID_PREFIX="Not a valid reply. Valid replies are:"
ENTER_TO_PROCEED="Press [Enter] to proceed"

DISCOVER_NEW_DEVICES_PROMPT="Would you like to discover new XIV Storage devices now?"

PLATFORM_NOT_SUPPORTED="Warning: This attachment kit provides EXPERIMENTAL support for this platform.\n" + \
                       "CAUTION: Features with experimental support are not intended for use in production environments\n" + \
                       "You may still proceed with the configuration at your own risk.\n" + \
                       " * Please refere the release notes of this attachment kit for information about platform support\n"
PLATFORM_NOT_SUPPORTED_CONFIRM="Please confirm that you wish to configure this host at your own risk by typing 'I understand': "

==> XIV_host_attach-1.1.1-suse-11-x64.tar.gz: opt/xiv/host_attach/lib/python/hostattachment/translation.py <==
WIZARD_BANNER="Welcome to the XIV host attachment wizard. This wizard will\n" + \
              "guide you through the process of attaching your host to the XIV system."
WIZARD_VALIDATE="The wizard will now validate host configuration for the XIV system."
WIZARD_SEPARATOR="-" * 79

ATTACHMENT_TYPE_PROMPT="Please choose a connectivity type, [f]c / [i]scsi:"
ONLY_ISCSI_PROMPT="Only ISCSI is supported on this platform. Would you like to set up an ISCSI attachment?"
ONLY_FC_PROMPT="Only fiber is supported on this platform. Would you like to set up an FC attachment?"

HOST_ALREADY_CONFIGURED="This host is already configured for the XIV system"
HOST_CONFIG_VALIDATION_NOTIFICATION="Please wait while the wizard validates your existing configuration..."
HOST_CONFIG_PROMPT="The wizard needs to configure the host for the XIV system, proceed?"
HOST_CONFIG_SUCCESS="The host is now configured for the XIV system"

HOST_CONFIGURED="The host is already configured for the XIV system"

NEW_ISCSI_CONNECT="Would you like to discover a new iSCSI target?"
ISCSI_CONNECT_ADDR="Enter an XIV iSCSI discovery address (iSCSI interface):"

FC_RESCAN_PROMPT="Would you like to rescan for fiber channel storage devices now?"
ISCSI_RESCAN_PROMPT="Would you like to rescan for iSCSI storage devices now?"

HOST_CONFIG_COMPLETE="The host was successfully configured for the XIV system"
WIZARD_ENDED="The XIV host attachment wizard successfully configured this host"

XIV_FC_HOST_DEFINE="Please define host and port in XIV storage system with the following fiber channel WWPNs:"
XIV_ISCSI_HOST_DEFINE="Please define host and port in XIV storage system with the following initiator name or initiator alias:"

USER_ABORT_CONFIRM="Are you sure you want to cancel the XIV host attachment configuration wizard?"
USER_ABORT="The operation was canceled"

REBOOT_REQUIRED="A reboot is required in order to continue. Please reboot the machine and restart the wizard"

HOST_CONFIG_WAIT="Please wait while the host is configured..."
HOST_RESCAN_WAIT="Please wait while rescanning for storage devices..."

INPUT_INVALID_PREFIX="Not a valid reply. Valid replies are:"
ENTER_TO_PROCEED="Press [Enter] to proceed"

DISCOVER_NEW_DEVICES_PROMPT="Would you like to discover new XIV Storage devices now?"

PLATFORM_NOT_SUPPORTED="Warning: This attachment kit provides EXPERIMENTAL support for this platform.\n" + \
                       "CAUTION: Features with experimental support are not intended for use in production environments\n" + \
                       "You may still proceed with the configuration at your own risk.\n" + \
                       " * Please refer the release notes of this attachment kit for information about platform support\n"
PLATFORM_NOT_SUPPORTED_CONFIRM="Please confirm that you wish to configure this host at your own risk by typing 'I understand': "

CONFLICTING_COMMANDS="Bad arguments: conflicting arguments were used. Please use one command at a time."
